gzkeyboard
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install gzkeyboard in Development mode

``` sh
# make sure gzkeyboard package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to gzkeyboard
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/AI4Basics/gzkeyboard):

``` sh
$ pip install git+https://github.com/AI4Basics/gzkeyboard.git
```

or from [conda](https://anaconda.org/AI4Basics/gzkeyboard)

``` sh
$ conda install -c AI4Basics gzkeyboard
```

or from [pypi](https://pypi.org/project/gzkeyboard/)

``` sh
$ pip install gzkeyboard
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/AI4Basics/gzkeyboard)’s
[pages](https://AI4Basics.github.io/gzkeyboard/). Additionally you can
find package manager specific guidelines on
[conda](https://anaconda.org/AI4Basics/gzkeyboard) and
[pypi](https://pypi.org/project/gzkeyboard/) respectively.

## How to use

Fill me in please! Don’t forget code examples:

``` python
1+1
```

    2
